@@ -12,11 +12,11 @@ get '/' => sub ($c) {
   my $model = $c->param('model');
   my $name = $c->param('name');
   my $group = $c->param('group');
-  my ($groups, $settings);
+  my ($models, $names, $groups, $settings);
   $model = trim($model);
   $name = trim($name);
+  my $synth = Synth::Config->new(model => $model);
   if ($model) {
-    my $synth = Synth::Config->new(model => $model);
     # get a specs config file for the synth model
     my $set = './eg/' . $synth->model . '.set';
     my $specs = -e $set ? do $set : undef;
@@ -32,11 +32,18 @@ get '/' => sub ($c) {
     elsif ($synth->model) {
       $settings = $synth->recall_all;
     }
+    $names = $synth->recall_names;
+  }
+  $models = $synth->recall_models;
+  for my $m (@$models) {
+    $m =~ s/_/ /g;
   }
   $c->render(
     template => 'index',
     model    => $model,
+    models   => $models,
     name     => $name,
+    names    => $names,
     group    => $group,
     groups   => $groups,
     settings => $settings,
@@ -175,18 +182,28 @@ __DATA__
 <div class="row">
   <div class="col">
     <label for="model" class="form-label">Model:</label>
-    <input name="model" id="model" value="<%= $model %>" class="form-control" required>
+    <select name="model" id="model" class="form-select" required>
+      <option value="">Model...</option>
+% for my $m (@$models) {
+      <option value="<%= $m %>" <%= $models && $m eq $model ? 'selected' : '' %>><%= ucfirst $m %></option>
+% }
+    </select>
   </div>
   <div class="col">
     <label for="name" class="form-label">Name:</label>
-    <input name="name" id="name" value="<%= $name %>" class="form-control">
+    <select name="name" id="name" class="form-select">
+      <option value="">Name...</option>
+% for my $n (@$names) {
+      <option value="<%= $n %>" <%= $names && $n eq $name ? 'selected' : '' %>><%= ucfirst $n %></option>
+% }
+    </select>
   </div>
   <div class="col">
     <label for="group" class="form-label">Group:</label>
     <select name="group" id="group" class="form-select">
       <option value="">Group...</option>
 % for my $g (@$groups) {
-      <option value="<%= $g %>" <%= $g eq $group ? 'selected' : '' %>><%= ucfirst $g %></option>
+      <option value="<%= $g %>" <%= $group && $g eq $group ? 'selected' : '' %>><%= ucfirst $g %></option>
 % }
     </select>
   </div>
@@ -194,8 +211,8 @@ __DATA__
 <p></p>
 <div class="row">
   <div class="col">
-    <input type="submit" value="Submit" class="btn btn-primary">
-    <a href="<%= url_for('edit')->query(model => $model, name => $name, group => $group) %>" class="btn btn-success">New setting</a>
+    <button type="submit" class="btn btn-primary"><i class="fa-solid fa-magnifying-glass"></i> Search</button>
+    <a href="<%= url_for('edit')->query(model => $model, name => $name, group => $group) %>" class="btn btn-success"><i class="fa-solid fa-plus"></i> New setting</a>
   </div>
 </div>
 </form>
@@ -218,7 +235,8 @@ __DATA__
 %     unit       => $setting->{unit},
 %     is_default => $setting->{is_default},
 %   );
-<a href="<%= $edit_url %>" class="btn btn-sm btn-outline-secondary">Edit</a>
+<a href="<%= $edit_url %>" class="btn btn-sm btn-outline-secondary"><i class="fa-solid fa-pencil"></i></a>
+&nbsp;
 <b>Name</b>: <%= $setting->{name} %> ,
 <b>Group</b>: <%= $setting->{group} %> ,
 <b>Param</b>: <i><%= $setting->{parameter} %></i> <%= $setting->{control} %>
@@ -292,9 +310,9 @@ __DATA__
   </div>
 </div>
   <p></p>
-  <input type="submit" value="Submit" class="btn btn-primary">
-  <a href="<%= url_for('remove')->query(id => $id, model => $model, name => $name) %>" class="btn btn-danger" onclick="if(!confirm('Remove setting <%= $id %>?')) return false;">Remove</a>
-  <a href="<%= url_for('index')->query(model => $model, name => $name) %>" class="btn btn-warning">Cancel</a>
+  <button type="submit" class="btn btn-primary"><i class="fa-solid fa-plus"></i> Submit</button>
+  <a href="<%= url_for('remove')->query(id => $id, model => $model, name => $name) %>" class="btn btn-danger" onclick="if(!confirm('Remove setting <%= $id %>?')) return false;"><i class="fa-solid fa-trash-can"></i> Remove</a>
+  <a href="<%= url_for('index')->query(model => $model, name => $name, group => $selected->{group}) %>" class="btn btn-warning"><i class="fa-solid fa-xmark"></i> Cancel</a>
 </form>
 
 <script>
@@ -379,6 +397,8 @@ $(document).ready(function() {
     <meta charset="utf-8">
     <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
     <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.0.2/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-EVSTQN3/azprG1Anm3QDgpJLIm9Nao0Yz1ztcQTwFspd3yD65VohhpuuCOmLASjC" crossorigin="anonymous">
+    <link href="/css/fontawesome.css" rel="stylesheet">
+    <link href="/css/solid.css" rel="stylesheet">
     <script src="https://cdn.jsdelivr.net/npm/jquery@3.7.0/dist/jquery.min.js"></script>
     <style>
       a:hover, a:visited, a:link, a:active { text-decoration: none; }
